==> abridge-sdk-1.0.5.tgz: package/config/nets.js <==
export const config = {
    "4": {
        "contracts": {
            "routerAddress": "0x6911F73a4DfDe160440689b1e4aC7fa266008457"
        },
        "validators": {
            "london": "https://abridge-relay-eu-west-2.allianceblock.io:5200",
            "north virginia": "https://abridge-relay-ap-southeast-1.allianceblock.io:5200",
            "singapore": "https://abridge-relay-us-east-1.allianceblock.io:5200"
        },
        "threshold": "1000000000000000"
    },
    "97": {
        "contracts": {
            "router": "0xFdccb7de1d2065217457840C4D7e17D57bFC8612с"
        },
        "validators": {
            "london": "https://abridge-relay-eu-west-2.allianceblock.io:5200",
            "north virginia": "https://abridge-relay-ap-southeast-1.allianceblock.io:5200",
            "singapore": "https://abridge-relay-us-east-1.allianceblock.io:5200"
        },
        "threshold": "1000000000000000"
    },
    "43113": {
        "contracts": {
            "router": "0xbbe95fbBC8890E17fBb9e2D33eD678045B1F83Ad"
        },
        "validators": {
            "london": "https://abridge-relay-eu-west-2.allianceblock.io:5200",
            "north virginia": "https://abridge-relay-ap-southeast-1.allianceblock.io:5200",
            "singapore": "https://abridge-relay-us-east-1.allianceblock.io:5200"
        },
        "threshold": "1000000000000000"
    },
    "80001": {
        "contracts": {
            "router": "0x51199130815e433450d5ccD300d69774CCD922DB"
        },
        "validators": {
            "london": "https://abridge-relay-eu-west-2.allianceblock.io:5200",
            "north virginia": "https://abridge-relay-ap-southeast-1.allianceblock.io:5200",
            "singapore": "https://abridge-relay-us-east-1.allianceblock.io:5200"
        },
        "threshold": "1000000000000000"
    },
    "73799": {
        "contracts": {
            "router": "0x0DC2D4892b14AF3C0f14755eCedB8aC0417B867B"
        },
        "validators": {
            "london": "https://abridge-relay-eu-west-2.allianceblock.io:5200",
            "north virginia": "https://abridge-relay-ap-southeast-1.allianceblock.io:5200",
            "singapore": "https://abridge-relay-us-east-1.allianceblock.io:5200"
        },
        "threshold": "1000000000000000"
    },
    "1": {
        "contracts": {
            "router": "0x7CAB80B6FaCD52A0F3e044D8bfC43d0ad6D258F4"
        },
        "validators": {
            "limechain": "https://alliance-bridge-validator.com",
            "allianceblock": "https://validator1.alliancebridge.io:5200",
        },
        "threshold": "1000000000000000"
    },
    "56": {
        "contracts": {
            "router": "0xc47d16ae45E1Df2242107C35Bb0C9a399e4e5598"
        },
        "validators": {
            "limechain": "https://alliance-bridge-validator.com",
            "allianceblock": "https://validator1.alliancebridge.io:5200",
        },
        "threshold": "1000000000000000"
    },
    "43114": {
        "contracts": {
            "router": "0xa5765ABE9f838F8a13d7c5dF933FDDF0409dC1eE"
        },
        "validators": {
            "limechain": "https://alliance-bridge-validator.com",
            "allianceblock": "https://validator1.alliancebridge.io:5200",
        },
        "threshold": "1000000000000000"
    },
    "137": {
        "contracts": {
            "router": "0xA16dfA9a67e6Aa054B2c0789B0c0Eb774371D004"
        },
        "validators": {
            "limechain": "https://alliance-bridge-validator.com",
            "allianceblock": "https://validator1.alliancebridge.io:5200",
        },
        "threshold": "1000000000000000"
    },
    "246": {
        "contracts": {
            "router": "0x8e442E46D7F009cAc7C1EE82D6453353aE7A463C"
        },
        "validators": {
            "limechain": "https://alliance-bridge-validator.com",
            "allianceblock": "https://validator1.alliancebridge.io:5200",
        },
        "threshold": "1000000000000000"
    }
};

==> abridge-sdk-1.0.7.tgz: package/config/nets.js <==
export const config = {
    "4": {
        "contracts": {
            "router": "0x6911F73a4DfDe160440689b1e4aC7fa266008457"
        },
        "validators": {
            "london": "https://abridge-relay-eu-west-2.allianceblock.io:5200",
            "north virginia": "https://abridge-relay-ap-southeast-1.allianceblock.io:5200",
            "singapore": "https://abridge-relay-us-east-1.allianceblock.io:5200"
        },
        "threshold": "1000000000000000"
    },
    "97": {
        "contracts": {
            "router": "0xFdccb7de1d2065217457840C4D7e17D57bFC8612"
        },
        "validators": {
            "london": "https://abridge-relay-eu-west-2.allianceblock.io:5200",
            "north virginia": "https://abridge-relay-ap-southeast-1.allianceblock.io:5200",
            "singapore": "https://abridge-relay-us-east-1.allianceblock.io:5200"
        },
        "threshold": "1000000000000000"
    },
    "43113": {
        "contracts": {
            "router": "0xbbe95fbBC8890E17fBb9e2D33eD678045B1F83Ad"
        },
        "validators": {
            "london": "https://abridge-relay-eu-west-2.allianceblock.io:5200",
            "north virginia": "https://abridge-relay-ap-southeast-1.allianceblock.io:5200",
            "singapore": "https://abridge-relay-us-east-1.allianceblock.io:5200"
        },
        "threshold": "1000000000000000"
    },
    "80001": {
        "contracts": {
            "router": "0x51199130815e433450d5ccD300d69774CCD922DB"
        },
        "validators": {
            "london": "https://abridge-relay-eu-west-2.allianceblock.io:5200",
            "north virginia": "https://abridge-relay-ap-southeast-1.allianceblock.io:5200",
            "singapore": "https://abridge-relay-us-east-1.allianceblock.io:5200"
        },
        "threshold": "1000000000000000"
    },
    "73799": {
        "contracts": {
            "router": "0x0DC2D4892b14AF3C0f14755eCedB8aC0417B867B"
        },
        "validators": {
            "london": "https://abridge-relay-eu-west-2.allianceblock.io:5200",
            "north virginia": "https://abridge-relay-ap-southeast-1.allianceblock.io:5200",
            "singapore": "https://abridge-relay-us-east-1.allianceblock.io:5200"
        },
        "threshold": "1000000000000000"
    },
    "1": {
        "contracts": {
            "router": "0x7CAB80B6FaCD52A0F3e044D8bfC43d0ad6D258F4"
        },
        "validators": {
            "limechain": "https://alliance-bridge-validator.com",
            "allianceblock": "https://validator1.alliancebridge.io:5200",
        },
        "threshold": "1000000000000000"
    },
    "56": {
        "contracts": {
            "router": "0xc47d16ae45E1Df2242107C35Bb0C9a399e4e5598"
        },
        "validators": {
            "limechain": "https://alliance-bridge-validator.com",
            "allianceblock": "https://validator1.alliancebridge.io:5200",
        },
        "threshold": "1000000000000000"
    },
    "43114": {
        "contracts": {
            "router": "0xa5765ABE9f838F8a13d7c5dF933FDDF0409dC1eE"
        },
        "validators": {
            "limechain": "https://alliance-bridge-validator.com",
            "allianceblock": "https://validator1.alliancebridge.io:5200",
        },
        "threshold": "1000000000000000"
    },
    "137": {
        "contracts": {
            "router": "0xA16dfA9a67e6Aa054B2c0789B0c0Eb774371D004"
        },
        "validators": {
            "limechain": "https://alliance-bridge-validator.com",
            "allianceblock": "https://validator1.alliancebridge.io:5200",
        },
        "threshold": "1000000000000000"
    },
    "246": {
        "contracts": {
            "router": "0x8e442E46D7F009cAc7C1EE82D6453353aE7A463C"
        },
        "validators": {
            "limechain": "https://alliance-bridge-validator.com",
            "allianceblock": "https://validator1.alliancebridge.io:5200",
        },
        "threshold": "1000000000000000"
    }
};
